@@ -3,7 +3,20 @@ package Coro::PatchSet::Handle;
 use strict;
 use Coro::Handle;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
+
+package # hide it from cpan
+	Coro::Handle;
+
+sub new_from_fh {
+	my $class = shift;
+	my $fh = shift or return;
+	open my $self, '+<&', $fh or return;
+	
+	tie *$self, 'Coro::Handle::FH', fh => $fh, @_;
+	
+	bless $self, ref $class ? ref $class : $class
+}
 
 package # hide it from cpan
 	Coro::Handle::FH;
@@ -64,6 +77,13 @@ Coro::PatchSet::Handle - fix Coro::Handle as much as possible
 
 =head1 PATCHES
 
+=head2 new_from_fh
+
+Coro::Handle::new_from_fh creates tied handle. In the current implementation it ties Glob which is not a real file
+handle. So things like IO::Handle::new_from_fd doesn't work with such tied handle. After this patch tied handle 
+will be a real filehandle (duplicate of original filehandle) and new_from_fd will work as expected. See
+t/07_handle_new_from_fd.t
+
 =head2 sysread()
 
 In the current Coro::Handle implementation sysread($buf, $len) will always try to read $len bytes. So if we have
